if [ ! -f /usr/share/Ted/config/Ted.properties ]
then
    /usr/bin/mkdir -p /usr/share/Ted/config
    /usr/bin/cp /etc/defaults/usr/share/Ted/config/Ted.properties /usr/share/Ted/config/Ted.properties
fi

/usr/bin/update-desktop-database /usr/share/applications
/usr/bin/update-mime-database -n /usr/share/mime

